/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: QTDE_UNIDADE_ESTOQUE

Descrio:
Retorna uma quantidade de um produto em uma determinada unidade convertida
na unidade de estoque de acordo com a tabela CONVPRODUTO.

P_QTORIGINAL - Quantidade Original.
P_SGUNIDADE  - Sigla da Unidade de Medida Original.
P_CDPRODUTO  - Cdigo do Produto.
P_SGUNIDPROD - Unidade do produto (evita abertura de cursor desnecessario)

Criao:
05/01/99 - Ederson

OBS: Convertida para SQL SERVER por Robert Pereira

Manutenes:
04/03/99 - ZED - INCLUSAO DO PARAMETRO OPCIONAL SGUNIDPROD

*/
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE 
	        O.NAME = 'QTDE_UNIDADE_ESTOQUE'  AND 
	        TYPE IN ('P') 			        AND
	        U.UID = O.UID             		        AND 
	        U.NAME = USER)

  DROP PROCEDURE QTDE_UNIDADE_ESTOQUE
  GO
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'QTDE_UNIDADE_ESTOQUE'  AND 
	        TYPE = 'FN' 			        AND
	        U.UID = O.UID             		        AND 
	        U.NAME = USER)

  DROP FUNCTION QTDE_UNIDADE_ESTOQUE
  GO

CREATE FUNCTION QTDE_UNIDADE_ESTOQUE
  (@P_QTORIGINAL NUMERIC(15,6),
   @P_SGUNIDADE   VARCHAR(5),
   @P_CDPRODUTO   VARCHAR(10),
   @P_SGUNIDPROD  VARCHAR(5) = NULL) RETURNS NUMERIC(15,6)
AS
BEGIN

   DECLARE @V_QTCONVERT     NUMERIC(15,6);
   DECLARE @V_VRFATOCONVES  NUMERIC(15,6);
   DECLARE @V_SGUNIDADE     VARCHAR(5);

   /* Faz a converso da unidade do produto na receita */

   SET @V_QTCONVERT = @P_QTORIGINAL;

   IF NOT @P_SGUNIDADE IS NULL
   BEGIN

      IF NOT @P_SGUNIDPROD IS NULL
      BEGIN
         SET @V_SGUNIDADE = @P_SGUNIDPROD;
      END
      ELSE
      BEGIN
         SELECT @V_SGUNIDADE = SGUNIDADE
         FROM PRODUTO
         WHERE (CDPRODUTO = @P_CDPRODUTO);
      END;

      IF (@V_SGUNIDADE <> @P_SGUNIDADE)
      BEGIN

         SELECT @V_VRFATOCONVES = MAX(VRFATOCONVES)
         FROM CONVPRODUTO
         WHERE (CDPRODUTO = @P_CDPRODUTO) AND
               (SGUNIDADE = @P_SGUNIDADE);

         IF NOT @V_VRFATOCONVES IS NULL
         BEGIN
            SET @V_QTCONVERT = @P_QTORIGINAL * @V_VRFATOCONVES;
         END
         ELSE
         BEGIN
            SELECT @V_VRFATOCONVES = MAX(VRFTCONVER)
            FROM CONVUNID
            WHERE (SGUNIDDE   = @P_SGUNIDADE) AND
                  (SGUNIDPARA = @V_SGUNIDADE);

            IF NOT @V_VRFATOCONVES IS NULL
            BEGIN
               SET @V_QTCONVERT = @P_QTORIGINAL * @V_VRFATOCONVES;
            END;
         END;
      END;
   END;
   RETURN(@V_QTCONVERT);
END
GO

-- VERSAO --
EXEC ATUVEROBJ 'QTDE_UNIDADE_ESTOQUE','4.05.133';
GO

